@@ -1,3 +1,5 @@
+//! Error types used with Tango.
+
 use std::error;
 use std::fmt;
 use std::ptr;
@@ -5,9 +7,11 @@ use std::ptr;
 use crate::c;
 use crate::types::{ErrSeverity, string_from};
 
+/// Convenience alias for a Result from Tango APIs.
 pub type TangoResult<R> = Result<R, TangoError>;
 
 
+/// Represents a single "entry" of a Tango error stack.
 #[derive(Debug)]
 pub struct TangoFailure {
     pub desc: String,
@@ -16,6 +20,7 @@ pub struct TangoFailure {
     pub severity: ErrSeverity,
 }
 
+/// A Tango error; corresponds to an exception thrown by the C++ API.
 #[derive(Debug)]
 pub struct TangoError {
     pub failures: Vec<TangoFailure>,
@@ -46,7 +51,7 @@ impl error::Error for TangoError {
 }
 
 impl TangoError {
-    pub fn from_stack(stackptr: *mut c::ErrorStack) -> TangoError {
+    pub(crate) fn from_stack(stackptr: *mut c::ErrorStack) -> TangoError {
         let stack = unsafe  { *stackptr };
         let mut seq = Vec::with_capacity(stack.length as usize);
         for i in 0..stack.length {
